import { isEnumType, isInputObjectType, isListType, isNonNullType, isScalarType, } from 'graphql';
const scalarTypesMap = {
    Int: 'integer',
    String: 'string',
    Float: 'number',
    ID: 'string',
    Boolean: 'boolean',
    DateTime: 'string',
};
const scalarType = (definition, type) => {
    var _a;
    definition.type = (_a = scalarTypesMap[type.name]) !== null && _a !== void 0 ? _a : 'any';
};
const listType = (definition, type) => {
    var _a;
    definition.type = 'array';
    definition.items = {
        type: (_a = scalarTypesMap[type.ofType]) !== null && _a !== void 0 ? _a : type.ofType,
    };
};
const enumType = (definition, type) => {
    definition.type = 'string';
    definition.enum = type.getValues().map(val => val.name);
};
const objectType = (definition, type) => {
    definition.type = 'object';
    const fields = type.getFields();
    if (!definition.properties) {
        definition.properties = {};
    }
    definition.required = [];
    Object.keys(fields).forEach(fieldName => {
        const { required, definition: fieldDefinition, } = getJSONSchemaFromGraphQLType(fields[fieldName].type);
        definition.properties[fieldName] = fieldDefinition;
        if (required) {
            definition.required.push(fieldName);
        }
    });
};
function getJSONSchemaFromGraphQLType(type) {
    let required = false;
    let definition = {};
    if ('description' in type) {
        definition.description = type.description;
    }
    if ('defaultValue' in type) {
        definition.default = type.defaultValue;
    }
    if (isEnumType(type)) {
        enumType(definition, type);
    }
    if (isInputObjectType(type)) {
        objectType(definition, type);
    }
    if (isListType(type)) {
        listType(definition, type);
    }
    if (isScalarType(type)) {
        scalarType(definition, type);
    }
    if (isNonNullType(type)) {
        required = true;
        definition = getJSONSchemaFromGraphQLType(type.ofType).definition;
    }
    return { required, definition };
}
export function getVariablesJSONSchema(variableToType) {
    const jsonSchema = {
        $schema: 'https://json-schema.org/draft/2020-12/schema',
        type: 'object',
        properties: {},
        required: [],
    };
    if (variableToType) {
        Object.entries(variableToType).forEach(([variableName, type]) => {
            var _a;
            const { definition, required } = getJSONSchemaFromGraphQLType(type);
            jsonSchema.properties[variableName] = definition;
            if (required) {
                (_a = jsonSchema.required) === null || _a === void 0 ? void 0 : _a.push(variableName);
            }
        });
    }
    return jsonSchema;
}
//# sourceMappingURL=getVariablesJSONSchema.js.map